@@ -5,11 +5,12 @@
 /*         Xavier Leroy and Damien Doligez, INRIA Rocquencourt         */
 /*                                                                     */
 /*  Copyright 1996 Institut National de Recherche en Informatique et   */
-/*  en Automatique.  Distributed only by permission.                   */
+/*  en Automatique.  All rights reserved.  This file is distributed    */
+/*  under the terms of the GNU Library General Public License.         */
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: alloc.h,v 1.5 1998/10/26 19:17:57 doligez Exp $ */
+/* $Id: alloc.h,v 1.9 2000/02/21 18:13:16 xleroy Exp $ */
 
 #ifndef _alloc_
 #define _alloc_
@@ -22,12 +23,20 @@ value alloc (mlsize_t, tag_t);
 value alloc_small (mlsize_t, tag_t);
 value alloc_tuple (mlsize_t);
 value alloc_string (mlsize_t);
-value alloc_final (mlsize_t, final_fun, mlsize_t, mlsize_t);
 value copy_string (char *);
 value copy_string_array (char **);
 value copy_double (double);
+value copy_int32 (int32);       /* defined in [ints.c] */
+value copy_int64 (int64);       /* defined in [ints.c] */
+value copy_nativeint (long);    /* defined in [ints.c] */
 value alloc_array (value (*funct) (char *), char ** array);
+
+typedef void (*final_fun)(value);
+value alloc_final (mlsize_t /*size in words*/,
+                   final_fun, /*finalization function*/
+                   mlsize_t, /*resources consumed*/
+                   mlsize_t  /*max resources*/);
+
 int convert_flag_list (value, int *);
 
-
 #endif /* _alloc_ */
