@@ -10,7 +10,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: config.h,v 1.17 1999/11/17 18:57:05 xleroy Exp $ */
+/* $Id: config.h,v 1.21 2000/04/05 18:30:11 doligez Exp $ */
 
 #ifndef _config_
 #define _config_
@@ -21,8 +21,12 @@
 #define SIZEOF_INT 4
 #define SIZEOF_LONG 4
 #define SIZEOF_SHORT 2
-#undef ARCH_BIG_ENDIAN
-#undef ARCH_ALIGN_DOUBLE
+#define ARCH_INT64_TYPE long long
+#define ARCH_UINT64_TYPE unsigned long long
+#define ARCH_INT64_PRINTF_FORMAT "ll"
+#define ARCH_BIG_ENDIAN
+#define ARCH_ALIGN_DOUBLE
+#define ARCH_ALIGN_INT64
 #define OCAML_OS_TYPE "Unix"
 #define HAS_MEMMOVE
 #define HAS_BCOPY
@@ -45,6 +49,7 @@
 #define HAS_FCHMOD
 #define HAS_TRUNCATE
 #define HAS_SELECT
+#define HAS_SYS_SELECT_H
 #define HAS_SYMLINK
 #define HAS_WAITPID
 #define HAS_WAIT4
@@ -58,9 +63,41 @@
 #define HAS_SETSID
 #define HAS_PUTENV
 #define HAS_LOCALE
+#define HAS_MMAP
 #else
+#include <m.h>
+#include <s.h>
 #endif
 
+/* Types for signed chars, 16-bit integers, 32-bit integers, 64-bit integers */
+
+typedef signed char schar;
+
+typedef short int16;            /* FIXME -- not true on the Cray T3E */
+typedef unsigned short uint16;  /* FIXME -- not true on the Cray T3E */
+
+#if SIZEOF_INT == 4
+typedef int int32;
+typedef unsigned int uint32;
+#elif SIZEOF_LONG == 4
+typedef long int32;
+typedef unsigned long uint32;
+#elif SIZEOF_SHORT == 4
+typedef short int32;
+typedef unsigned short uint32;
+#endif
+
+#if defined(ARCH_INT64_TYPE) && defined(ARCH_UINT64_TYPE)
+typedef ARCH_INT64_TYPE int64;
+typedef ARCH_UINT64_TYPE uint64;
+#else
+/* Int64.t will not be supported, and operations over it are not defined,
+   but we must define the types int64 and uint64 as 64-bit placeholders. */
+typedef struct { uint32 a, b; } uint64;
+typedef uint64 int64;
+#endif
+
+
 /* Library dependencies */
 
 #ifdef HAS_MEMMOVE
@@ -86,9 +123,6 @@
 #define THREADED_CODE
 #endif
 
-/* Signed char type */
-
-typedef signed char schar;
 
 /* Do not change this definition. */
 #define Page_size (1 << Page_log)
