@@ -10,7 +10,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: mlvalues.h,v 1.25 1999/11/17 18:57:13 xleroy Exp $ */
+/* $Id: mlvalues.h,v 1.31 2000/04/07 14:43:31 xleroy Exp $ */
 
 #ifndef _mlvalues_
 #define _mlvalues_
@@ -34,6 +34,7 @@
   op: Pointer to the first field of a block.  (a value *)
   hp: Pointer to the header of a block.  (a char *)
   int32: Four bytes on all architectures.
+  int64: Eight bytes on all architectures.
 
   Remark: A block size is always a multiple of the word size, and at least
           one word plus the header.
@@ -56,17 +57,6 @@ typedef unsigned int tag_t;             /* Actually, an unsigned char */
 typedef unsigned long color_t;
 typedef unsigned long mark_t;
 
-#if SIZEOF_INT == 4
-typedef int int32;
-typedef unsigned int uint32;
-#elif SIZEOF_LONG == 4
-typedef long int32;
-typedef unsigned long uint32;
-#elif SIZEOF_SHORT == 4
-typedef short int32;
-typedef unsigned short uint32;
-#endif
-
 /* Longs vs blocks. */
 #define Is_long(x)   (((x) & 1) != 0)
 #define Is_block(x)  (((x) & 1) == 0)
@@ -186,6 +176,9 @@ typedef opcode_t * code_t;
 #define Class_val(val) Field(val, 0)
 #define Oid_val(val) Long_val(Field(val, 1))
 
+/* Another special case: variants */
+extern value hash_variant(char * tag);
+
 /* 2- If tag >= No_scan_tag : a sequence of bytes. */
 
 /* Pointer to the first byte */
@@ -222,13 +215,24 @@ void Store_double_val (value,double);
 #define Store_double_field(v,i,d) \
   Store_double_val((value)((double *)(v) + (i)),d)
 
-/* Finalized things.  Just like abstract things, but the GC will call the
-   [Final_fun] before deallocation.
-*/
-#define Final_tag 255
-typedef void (*final_fun) (value);
-#define Final_fun(val) (((final_fun *) (val)) [0]) /* Also an l-value. */
+/* Custom blocks.  They contain a pointer to a "method suite"
+   of functions (for finalization, comparison, hashing, etc)
+   followed by raw data.  The contents of custom blocks is not traced by
+   the GC; therefore, they must not contain any [value].
+   See [custom.h] for operations on method suites. */
+#define Custom_tag 255
+#define Data_custom_val(v) ((void *) &Field(v, 1))
+struct custom_operations;       /* defined in [custom.h] */
 
+/* Int32.t, Int64.t and Nativeint.t are represented as custom blocks. */
+
+#define Int32_val(v) (*((int32 *) Data_custom_val(v)))
+#define Nativeint_val(v) (*((long *) Data_custom_val(v)))
+#ifndef ARCH_ALIGN_INT64
+#define Int64_val(v) (*((int64 *) Data_custom_val(v)))
+#else
+extern int64 Int64_val(value v);
+#endif
 
 /* 3- Atoms are 0-tuples.  They are statically allocated once and for all. */
 
