@@ -5,13 +5,14 @@
 (*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
 (*                                                                     *)
 (*  Copyright 1996 Institut National de Recherche en Informatique et   *)
-(*  en Automatique.  Distributed only by permission.                   *)
+(*  en Automatique.  All rights reserved.  This file is distributed    *)
+(*  under the terms of the GNU Library General Public License.         *)
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: pervasives.ml,v 1.34 1999/02/24 15:21:47 xleroy Exp $ *)
+(* $Id: pervasives.ml,v 1.38 1999/11/30 16:06:56 garrigue Exp $ *)
 
-type 'a option = None | Some of 'a
+(* type 'a option = None | Some of 'a *)
 
 (* Exceptions *)
 
@@ -147,7 +148,7 @@ let string_of_bool b =
 let bool_of_string = function
   | "true" -> true
   | "false" -> false
-  | _ -> invalid_arg "string_of_bool"
+  | _ -> invalid_arg "bool_of_string"
 
 let string_of_int n =
   format_int "%d" n
@@ -196,6 +197,7 @@ let open_out name =
 let open_out_bin name =
   open_out_gen [Open_wronly; Open_creat; Open_trunc; Open_binary] 0o666 name
 
+external fflush : out_channel -> unit = "caml_flush"
 external flush : out_channel -> unit = "caml_flush"
 
 external unsafe_output : out_channel -> string -> int -> int -> unit
