@@ -5,11 +5,12 @@
 (*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
 (*                                                                     *)
 (*  Copyright 1996 Institut National de Recherche en Informatique et   *)
-(*  en Automatique.  Distributed only by permission.                   *)
+(*  en Automatique.  All rights reserved.  This file is distributed    *)
+(*  under the terms of the GNU Library General Public License.         *)
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: string.ml,v 1.17 1999/03/01 20:59:54 xleroy Exp $ *)
+(* $Id: string.ml,v 1.19 2000/01/12 15:53:18 doligez Exp $ *)
 
 (* String operations *)
 
@@ -154,7 +155,7 @@ let rec rindex_rec s i c =
 let rindex s c = rindex_rec s (length s - 1) c;;
 
 let rindex_from s i c =
-  if i < 0 || i >= length s then invalid_arg "String.rindex_from" else
+  if i < -1 || i >= length s then invalid_arg "String.rindex_from" else
   rindex_rec s i c;;
 
 let contains_from s i c =
